@@ -11,13 +11,17 @@
             "input[name*=login i]",
             "input[name*=user i]",
             "input[name*=email i]",
+            "input[name*=alias i]",
             "input[id*=login i]",
             "input[id*=user i]",
             "input[id*=email i]",
+            "input[id*=alias i]",
             "input[class*=login i]",
             "input[class*=user i]",
             "input[class*=email i]",
+            "input[class*=alias i]",
             "input[type=email i]",
+            "input[autocomplete=email i]",
             "input[type=text i]",
             "input[type=tel i]"
         ],
@@ -261,7 +265,8 @@
                 if (
                     rect.x + rect.width < 0 ||
                     rect.y + rect.height < 0 ||
-                    (rect.x > window.innerWidth || rect.y > window.innerHeight)
+                    rect.x > window.innerWidth ||
+                    rect.y > window.innerHeight
                 ) {
                     continue;
                 }
@@ -409,7 +414,13 @@
             el.dispatchEvent(new Event(eventName, { bubbles: true }));
         }
 
+        // truncate the value if required by the field
+        if (el.maxLength > 0) {
+            value = value.substr(0, el.maxLength);
+        }
+
         // Set the field value
+        let initialValue = el.value || el.getAttribute("value");
         el.setAttribute("value", value);
         el.value = value;
 
@@ -418,6 +429,13 @@
             el.dispatchEvent(new Event(eventName, { bubbles: true }));
         }
 
+        // re-set value if unchanged after firing post-fill events
+        // (in case of sabotage by the site's own event handlers)
+        if ((el.value || el.getAttribute("value")) === initialValue) {
+            el.setAttribute("value", value);
+            el.value = value;
+        }
+
         // Finally unfocus the element
         el.dispatchEvent(new Event("blur", { bubbles: true }));
         return true;
